<?php

namespace TotalPoll\Modules\Extensions\EmailCapture\Services;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Entry\Model as EntryModel;
use TotalPoll\Modules\Extensions\EmailCapture\Extension;
use TotalPoll\Poll\Model as PollModel;
use WP_Error;

class MailChimp extends AbstractService {
	/**
	 * @param EntryModel $entry
	 * @param PollModel $poll
	 *
	 * @return mixed|void
	 */
	public function handle( EntryModel $entry, PollModel $poll ) {
		$apiKey    = $this->extension->getOption( 'services.mailchimp.key', null );
		$apiPrefix = $this->extension->getOption( 'services.mailchimp.prefix', null );
		$list      = $this->extension->getOption( 'services.mailchimp.audience', null );
		$email     = $entry->getField( $this->extension->getEmailField() );
		$response  = $this->registerMember( $apiKey, $apiPrefix, $list, $email );

		if ( $response instanceof WP_Error ) {
			TotalPoll( 'log.repository' )->create(
				[
					'poll_id' => $poll->getId(),
					'action'  => 'Email Capture',
					'status'  => 'Failed',
					'choices' => [],
					'details' => $response->errors,
				]
			);
		}
	}

	/**
	 * @param $key
	 * @param $prefix
	 * @param $list
	 * @param $email
	 *
	 * @return bool|WP_Error
	 */
	protected function registerMember( $key, $prefix, $list, $email ) {
		$request = curl_init();
		$payload = json_encode( [
			'email_address'         => $email,
			'email_type'            => 'html',
			'status'                => $this->extension->getOption( 'services.mailchimp.status', 'pending' ),
			'language'              => '',
			'vip'                   => false,
			'marketing_permissions' => [],
			'ip_signup'             => '',
			'timestamp_signup'      => '',
			'ip_opt'                => '',
			'timestamp_opt'         => '',
			'tags'                  => []
		] );

		curl_setopt( $request, CURLOPT_URL, "https://{$prefix}.api.mailchimp.com/3.0/lists/{$list}/members?skip_merge_validation=1" );
		curl_setopt( $request, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $request, CURLOPT_POSTFIELDS, $payload );
		curl_setopt( $request, CURLOPT_HTTPHEADER, array( 'Content-Type:application/json' ) );
		curl_setopt( $request, CURLOPT_USERPWD, "totalpoll:{$key}" );
		curl_setopt( $request, CURLOPT_HTTPAUTH, CURLAUTH_BASIC );

		$response = curl_exec( $request );

		$status = (int) curl_getinfo( $request, CURLINFO_HTTP_CODE );

		if ( $status !== 200 ) {
			return new WP_Error( $status, $response );
		}

		curl_close( $request );

		return true;
	}

	/**
	 * @param Extension $extension
	 */
	static function renderSettings( Extension $extension ) {
		include_once $extension->getPath( 'views/mailchimp.php' );
	}
}