<?php

namespace TotalPoll\Modules\Extensions\GoogleAnalytics;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Poll\Model;
use TotalPollVendors\TotalCore\Helpers\Strings;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\GoogleAnalytics
 */
class Extension extends \TotalPoll\Modules\Extension {
	protected $root = __FILE__;

	/**
	 * Run the extension.
	 *
	 */
	public function run() {
		add_action( 'totalpoll/actions/after/admin/options/tabs/content', [ $this, 'render' ] );

		// send, event, Polls,
		add_action( 'totalpoll/actions/after/poll/command/vote', [ $this, 'onVote' ] );
	}

	public function onVote() {
		if ( TotalPoll()->option( 'services.ga.enabled', false ) ) {
			add_filter( 'totalpoll/filters/render/args', [ $this, 'sendEvent' ], 10, 2 );
		}
	}

	/**
	 * @param array $args
	 * @param Model $poll
	 *
	 * @return array
	 */
	public function sendEvent( array $args, Model $poll ) {
		foreach ( $poll->getReceivedChoices() as $choice ) {
			$question   = $poll->getQuestion( $choice['questionUid'] )['content'];
			$args['js'] .= Strings::template( '<script>window["ga"] && (window["gtag"] ? ga.getAll()[0].send("event", {{payload}}) : ga("send", "event", {{payload}}))</script>',
				[
					'payload' => json_encode( [
						'eventCategory'  => $question ?: $poll->getTitle(),
						'eventAction'    => 'vote',
						'eventLabel'     => $choice['label'],
						'nonInteraction' => TotalPoll()->option( 'services.ga.nonInteraction', false )
					], JSON_UNESCAPED_UNICODE )
				] );
		}

		return $args;
	}

	/**
	 * @param $tab
	 */
	public function render( $tab ) {
		if ( $tab === 'services' ) {
			include_once $this->getPath( 'views/index.php' );
		}
	}
}
