"use strict";
var TotalPoll;
(function (TotalPoll) {
    var LiveResults = /** @class */ (function () {
        function LiveResults($poll) {
            this.$poll = $poll;
            this.data = {};
            this.settings = {
                data: [],
                type: 'doughnut',
                options: {
                    legendCallback: function (chart) {
                        var text = [];
                        text.push('<div class="live-results-items">');
                        text.push("<h3 class=\"live-results-title\">" + chart.data.title + "</h3>");
                        for (var i = 0; i < chart.data.datasets[0].data.length; i++) {
                            text.push('<div class="live-results-item">');
                            text.push("<div class=\"live-results-item-text\">" + chart.data.labels[i] + "</div>");
                            text.push("<div class=\"live-results-item-percentage\"><div class=\"live-results-item-percentage-text\" style=\"background-color:" + chart.data.datasets[0].backgroundColor[i] + ";\"><span>" + chart.data.datasets[0].text[i] + "</span></div><div class=\"live-results-item-percentage-bar\" style=\"background-color:" + chart.data.datasets[0].backgroundColor[i] + "; width: " + chart.data.datasets[0].text[i] + ";\">&nbsp;</div></div>");
                            text.push('</div>');
                        }
                        text.push('</div>');
                        return text.join("");
                    },
                    legend: {
                        display: false,
                        position: 'right',
                        labels: {
                            fontSize: 28,
                            fontStyle: 'bold',
                            boxWidth: 50,
                            padding: 30
                        },
                    },
                    animation: {
                        duration: '1000',
                        easing: 'easeOutQuart',
                        animateScale: true,
                        animateRotate: true
                    },
                    title: {
                        display: false,
                    }
                }
            };
            this.canvasTemplate = "<canvas class=\"totalpoll-live-polling-chart\" width=\"400\" height=\"300\"></canvas>";
            this.charts = {};
            this.parseUrl();
            this.parseChartParams();
            this.parseData();
            this.prepareCharts();
            setInterval(this.refresh.bind(this), 3000);
        }
        LiveResults.prototype.fetchData = function () {
            return jQuery.get(this.url)
                .then(function (response) { return response.data.questions; });
        };
        LiveResults.prototype.getColors = function () {
            return ['#f94144', '#f3722c', '#f8961e', '#f9c74f', '#90be6d', '#43aa8b', '#577590', '#067bc2', '#84bcda', '#000000',]
                .sort(function () {
                return 0.5 - Math.random();
            });
        };
        LiveResults.prototype.parseData = function () {
            this.updateData(this.transformDataToChartData(JSON.parse(this.$poll.attr('totalpoll-live-polling-data'))));
        };
        LiveResults.prototype.parseUrl = function () {
            this.url = this.$poll.attr('totalpoll-live-polling-url');
        };
        LiveResults.prototype.parseChartParams = function () {
            this.settings.type = this.$poll.attr('totalpoll-live-polling-chart-type') || 'doughnut';
            this.settings.options.legend.visible = Boolean(this.$poll.attr('totalpoll-live-polling-chart-legend'));
            if ((this.settings.type === 'doughnut' || this.settings.type === 'pie') && !this.settings.options.legend.visible) {
                this.settings.options.legend.display = true;
            }
        };
        LiveResults.prototype.prepareCharts = function () {
            for (var questionUid in this.data) {
                var chart = {
                    dom: jQuery(this.canvasTemplate).appendTo(this.$poll).get(0),
                    settings: jQuery.extend(true, {}, this.settings, {
                        data: this.data[questionUid],
                        options: {
                            title: {
                                text: this.data[questionUid].title
                            }
                        }
                    }),
                    instance: null
                };
                chart.instance = new Chart(chart.dom, chart.settings);
                this.charts[questionUid] = chart;
                if (this.settings.options.legend.visible) {
                    this.$legend = jQuery('<div></div>').appendTo(this.$poll).html(chart.instance.generateLegend());
                }
            }
        };
        LiveResults.prototype.refresh = function () {
            this.fetchData()
                .then(this.transformDataToChartData.bind(this))
                .then(this.updateData.bind(this))
                .then(this.updateCharts.bind(this));
        };
        LiveResults.prototype.transformDataToChartData = function (data) {
            var colors = this.getColors();
            var dataset = {};
            for (var questionUid in data) {
                dataset[questionUid] = { title: data[questionUid]['content'], labels: [], datasets: [{ data: [], text: [], backgroundColor: [] }] };
                for (var choiceUid in data[questionUid]['choices']) {
                    if (colors.length == 0) {
                        colors = this.getColors();
                    }
                    dataset[questionUid]['labels'].push("" + data[questionUid]['choices'][choiceUid].label);
                    dataset[questionUid]['datasets'][0]['data'].push(data[questionUid]['choices'][choiceUid].votes);
                    dataset[questionUid]['datasets'][0]['text'].push(data[questionUid]['choices'][choiceUid].votesFormatted);
                    dataset[questionUid]['datasets'][0]['backgroundColor'].push(data[questionUid]['choices'][choiceUid].color || colors.pop());
                }
            }
            return dataset;
        };
        LiveResults.prototype.transformDataToChartDatasets = function (data) {
            var colors = this.getColors();
            var dataset = {};
            for (var questionUid in data) {
                dataset[questionUid] = { title: data[questionUid]['content'], labels: ['Choices'], datasets: [] };
                var index = 0;
                for (var choiceUid in data[questionUid]['choices']) {
                    dataset[questionUid]['datasets'][index] = { data: [data[questionUid]['choices'][choiceUid].votes], label: data[questionUid]['choices'][choiceUid].label, backgroundColor: data[questionUid]['choices'][choiceUid].color || colors.pop() };
                    index++;
                }
            }
            return dataset;
        };
        LiveResults.prototype.updateCharts = function () {
            var _this = this;
            var _loop_1 = function (questionUid) {
                var chart = this_1.charts[questionUid].instance;
                this_1.data[questionUid].datasets[0].data.forEach(function (val, index) {
                    chart.data.datasets[0].data[index] = val;
                    chart.data.datasets[0].text[index] = _this.data[questionUid].datasets[0].text[index];
                });
                this_1.data[questionUid].labels.forEach(function (label, index) {
                    chart.data.labels[index] = label;
                });
                chart.update(1000);
                if (this_1.$legend) {
                    this_1.$legend.html(chart.generateLegend());
                }
            };
            var this_1 = this;
            for (var questionUid in this.charts) {
                _loop_1(questionUid);
            }
        };
        LiveResults.prototype.updateData = function (data) {
            this.data = data;
        };
        return LiveResults;
    }());
    TotalPoll.LiveResults = LiveResults;
    jQuery(function ($) {
        $('.totalpoll-live-polling').each(function () {
            var $poll = $(this);
            $poll.data('live-polling', new LiveResults($poll));
        });
    });
})(TotalPoll || (TotalPoll = {}));

//# sourceMappingURL=maps/live-polling.js.map
