<?php

namespace TotalPoll\Modules\Extensions\PollUID;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Contracts\Poll\Model;
use TotalPollVendors\TotalCore\Helpers\Misc;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\PollUID
 */
class Extension extends \TotalPoll\Modules\Extension {
	protected $root = __FILE__;

	/**
	 * Run the extension.
	 *
	 * @return mixed
	 */
	public function run() {
		add_filter( 'totalpoll/filters/poll/prefix', [ $this, 'prefix' ], 10, 3 );
		add_filter( 'totalpoll/filters/admin/editor/defaults', [ $this, 'addUidToDefaults' ] );
		add_filter( 'totalpoll/filters/before/admin/editor/save/settings', [ $this, 'processSettings' ], 10, 3 );
		add_filter( 'totalpoll/filters/admin/editor/settings/tabs', [ $this, 'tab' ] );
	}


	/**
	 * Filters poll prefix.
	 *
	 * @param string $prefix
	 * @param string $append
	 * @param Model  $poll
	 *
	 * @return string
	 */
	public function prefix( $prefix, $append, $poll ) {
		$uid = $poll->getSettingsItem( 'pollUid' );

		if ( $uid ):
			$prefix = "{$prefix}_{$uid}";
		endif;

		return $prefix;
	}

	/**
	 * Filters poll defaults.
	 *
	 * @param $defaults
	 *
	 * @return string
	 */
	public function addUidToDefaults( $defaults ) {
		$defaults['pollUid'] = Misc::generateUid();

		return $defaults;
	}

	/**
	 * Filters settings.
	 *
	 * @param array $settings
	 *
	 * @param array $pollArgs
	 * @param int   $pollId
	 *
	 * @return array
	 */
	public function processSettings( $settings, $pollArgs, $pollId ) {
		if ( ! empty( $settings['uid']['regenerate'] ) ):
			$settings['pollUid'] = Misc::generateUid();
		endif;

		if ( ! empty( $settings['uid']['clearLog'] ) && $pollId ):
			TotalPoll( 'log.repository' )->delete( [
				'poll_id' => $pollId,
				'action'  => 'vote',
			] );
		endif;

		unset( $settings['uid'] );

		return $settings;
	}

	public function tab( $tabs ) {
		$tabs['vote']['tabs']['uid'] = [
			'label' => esc_html__( 'Unique ID', 'totalpoll' ),
			'icon'  => 'admin-generic',
			'file'  => $this->getPath( 'views/tab.php' ),
		];

		return $tabs;
	}
}
