<?php

namespace TotalPoll\Modules\Extensions\Redirection;
! defined( 'ABSPATH' ) && exit();


use TotalPollVendors\TotalCore\Http\Request;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\Redirection
 */
class Extension extends \TotalPoll\Modules\Extension {
	protected $root = __FILE__;

	/**
	 * Run the extension.
	 *
	 * @return mixed
	 */
	public function run() {
		add_filter( 'totalpoll/filters/render/output', [ $this, 'redirect' ], 10, 2 );
		add_filter( 'totalpoll/filters/admin/editor/settings/tabs', [ $this, 'tab' ] );
	}

	public function redirect( $output, $poll ) {

		$url    = trim( $poll->getSettingsItem( 'extra.redirect.url' ) );
		$target = trim( $poll->getSettingsItem( 'extra.redirect.target' ) );

		if(empty($url)) {
			return $output;
		}

		$redirected = TotalPoll('http.request')->request('redirected', false);
		$currentUrl = home_url(TotalPoll('http.request')->server('REQUEST_URI'));

		// Skip redirect to same url to avoid redirect loop
		if($redirected || rtrim($url, '/') == rtrim($currentUrl, '/')) return $output;

		$url = add_query_arg('redirected', '1', $url);

		if ( ! empty( $url ) && $poll->isVoteScreen() && $target === '_blank' ):
			$js = esc_attr( sprintf( "window.open('%s', '_blank')", esc_js( $url ) ) );

			return str_replace( 'name="totalpoll[action]" value="vote"', "name=\"totalpoll[action]\" value=\"vote\" onclick=\"{$js}\"", $output );
		endif;

		if ( ! empty( $url ) && ( $poll->isResultsScreen() || $poll->isThankYouScreen() ) ):
			if ( $target === '_blank' ):
				return '';
			else:
				return sprintf( "<script>top.location = '%s'</script>", esc_js( $url ) );
			endif;
		endif;

		return $output;
	}

	public function tab( $tabs ) {
		$tabs['redirect'] = [
			'label' => esc_html__( 'Redirection', 'totalpoll' ),
			'icon'  => 'randomize',
			'file'  => $this->getPath( 'views/tab.php' ),
		];

		return $tabs;
	}
}
