<?php

namespace TotalPoll\Modules\Extensions\RevealResultsByEmail;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Poll\Model;
use TotalPollVendors\TotalCore\Form\Fields\TextField;
use TotalPollVendors\TotalCore\Helpers\Html;
use TotalPollVendors\TotalCore\Helpers\Misc;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\RevealResultsByEmail
 */
class Extension extends \TotalPoll\Modules\Extension {
	protected $root = __FILE__;

	/**
	 * @var bool
	 */
	protected $reveal = false;

	/**
	 * Run the extension.
	 *
	 * @return mixed
	 */
	public function run() {
		add_filter( 'totalpoll/filters/render/vars', [ $this, 'prepare' ], 10, 2 );
		add_filter( 'totalpoll/filters/render/args', [ $this, 'handle' ], 10, 2 );
		add_filter( 'totalpoll/filters/admin/editor/settings/tabs', [ $this, 'tab' ] );
		add_filter( 'totalpoll/filters/poll/settings-item/fields', [ $this, 'fields' ] );
		add_action( 'totalpoll/actions/request/reveal', [ $this, 'handleRequest' ] );
	}

	public function handleRequest() {
		$pollId = (int) TotalPoll( 'http.request' )->request( 'totalpoll.pollId' );
		$email  = (string) TotalPoll( 'http.request' )->request( 'totalpoll.fields.email' );
		/**
		 * @var Model $poll
		 */
		$poll = TotalPoll( 'polls.repository' )->getById( $pollId );
		$poll->setScreen( Model::RESULTS_SCREEN );

		if ( is_email( $email ) ) {
			$log = TotalPoll( 'log.repository' )->create(
				[
					'poll_id' => $poll->getId(),
					'action'  => 'Reveal Results',
					'status'  => 'Accepted',
					'choices' => [],
					'details' => [ 'email' => $email ],
				]
			);

			$entry = TotalPoll( 'entries.repository' )->create(
				[
					'poll_id' => $poll->getId(),
					'log_id'  => $log->getId(),
					'fields'  => [
						'email' => $email
					],
					'details' => [],
				]
			);

			$poll->setCookie( $poll->generateCookieName( 'reveal' ), 1, 0 );

			$this->reveal = true;
		}
	}

	/**
	 * @param array $fields
	 *
	 * @return array
	 */
	public function fields( $fields ) {
		if ( is_admin() ) {
			if ( ! empty( $_POST['totalpoll'] ) && Misc::isDoingAjax() ) {
				return $fields;
			}

			$fields[] = [
				'uid'          => 'email',
				'name'         => 'email',
				'type'         => 'text',
				'label'        => esc_html__( 'Email', 'totalpoll' ),
				'defaultValue' => '',
				'options'      => [],
				'validations'  => [
					'filled' => [ 'enabled' => true ],
					'email'  => [ 'enabled' => true ],
				],
			];
		}

		return $fields;
	}

	public function prepare( $vars, Model $poll ) {
		$disabled = $poll->getSettingsItem( 'revealResults.disable', false );

		if ( empty( $disabled ) && $poll->isResultsScreen() && ! $poll->getCookie( $poll->generateCookieName( 'reveal' ) ) && ! $this->reveal ):
			$questions = $poll->offsetGet( 'questions' );
			foreach ( $questions as $questionUid => $question ):
				foreach ( $question['choices'] as $choiceUid => $choice ):
					$choice['votes'] = $choice['votesOverride'] = $choice['receivedVotes'] = $choice['rank'];
					$choice['type'] = 'text';
					$choice['label'] = 'Hidden';
					$poll->setChoice( $choiceUid, $choice, false );
				endforeach;
			endforeach;

			$poll->setAction( 'hide' );
		endif;

		return $vars;
	}

	public function handle( $args, Model $poll ) {
		if ( $poll->getAction() === 'hide' ):
			ob_start();
			$message = $poll->getSettingsItem( 'revealResults.message' ) ?: esc_html__( 'Please enter your email address to reveal the results.', 'totalpoll' );
			$field   = new TextField();
			$field->setOptions( [
				'uid'          => 'email',
				'name'         => 'totalpoll[fields][email]',
				'type'         => 'text',
				'label'        => esc_html__( 'Email', 'totalpoll' ),
				'defaultValue' => '',
				'options'      => [],
				'validations'  => [
					'filled' => [ 'enabled' => true ],
					'email'  => [ 'enabled' => true ],
				],
			] );
			$value = TotalPoll( 'http.request' )->post( "totalpoll.fields.email", empty( $_POST['totalpoll']['fields'] ) ? null : '' );
			$field->setValue( $value );
			if ( ! empty( $value ) ):
				$field->validate();
			endif;

			$button = new Html(
				'button',
				[
					'type'  => 'submit',
					'name'  => 'totalpoll[action]',
					'value' => 'reveal',
					'class' => 'totalpoll-button totalpoll-button-primary totalpoll-buttons-reveal',
				],
			 esc_html__( 'Reveal', 'totalpoll' )
			);
			include 'views/lock.php';
			$args['view'] .= ob_get_clean();
		endif;

		return $args;
	}

	public function tab( $tabs ) {
		$tabs['reveal-results'] = [
			'label' => esc_html__( 'Results reveal', 'totalpoll' ),
			'icon'  => 'hidden',
			'file'  => $this->getPath( 'views/tab.php' ),
		];

		return $tabs;
	}
}
