<?php

namespace TotalPoll\Modules\Extensions\SocialMediaAuth;
! defined( 'ABSPATH' ) && exit();


use TotalPollVendors\TotalCore\Contracts\Http\Request;

/**
 * Class Restriction
 * @package TotalPoll\Modules\Extensions\SocialMediaAuth
 */
class Restriction extends \TotalPoll\Restrictions\Restriction {
	/**
	 * @var Request
	 */
	protected $request;
	/**
	 * @var string
	 */
	protected $provider;
	/**
	 * @var string
	 */
	protected $token;
	/**
	 * @var array
	 */
	protected $user = [];

	public function __construct( $args ) {
		parent::__construct( $args );
		$this->request  = TotalPoll( 'http.request' );
		$this->provider = $this->request['totalpoll.sma.provider'];
		$this->token    = $this->request['totalpoll.sma.token'];

		add_filter( 'totalpoll/filters/poll/command/log/attributes', function ( $attributes ) {
			$attributes['details']['sma'] = [ 'token' => $this->token, 'provider' => $this->provider, 'user' => $this->user ];

			return $attributes;
		} );
	}

	/**
	 * @return bool|\WP_Error
	 */
	public function check() {
		$result = true;
		$action = $this->request['totalpoll.action'];

		if ( $action === 'vote' ):

			$enabledAccessToken = apply_filters( "totalpoll/filters/sma/provider/{$this->provider}/enabled", false );

			if ( ! $enabledAccessToken ):
				return new \WP_Error( 'sma_disabled_access_token', esc_html__( 'The provider you have used has been disabled.', 'totalpoll' ) );
			endif;

			$this->user = apply_filters( "totalpoll/filters/sma/provider/{$this->provider}/retrieve", $this->token, $this->request );

			if ( empty( $this->user ) ):
				return new \WP_Error( 'sma_invalid_access_token', esc_html__( 'Invalid access token. Please re-authenticate again.', 'totalpoll' ) );
			endif;

			$timeout    = (int) $this->getTimeout();
			$conditions = [
				'poll_id' => $this->getPollId(),
				'action'  => $this->getAction(),
				'status'  => 'accepted',
				'date'    => [],
				'details' => [
					[
						'operator' => 'LIKE',
						'value'    => "%{$this->user['uid']}%",
					],
				],
			];

			if ( $timeout !== 0 ):
				$date                 = TotalPoll( 'datetime', [ "-{$timeout} minutes" ] );
				$conditions['date'][] = [ 'operator' => '>', 'value' => $date->format( 'Y/m/d H:i:s' ) ];
			endif;

			$count = TotalPoll( 'log.repository' )->count( [ 'conditions' => $conditions, ] );

			if ( $count >= $this->getVotesPerSession() ):
				$result = false;
			endif;

		endif;

		return $result ?: new \WP_Error( 'sma_voted', esc_html__( 'You cannot vote again.', 'totalpoll' ) );
	}

	/**
	 * Apply Restriction.
	 */
	public function apply() {

	}
}
