"use strict";
var TotalPoll;
(function (TotalPoll) {
    var jQuery = window['jQuery'];
    var AuthUser = /** @class */ (function () {
        function AuthUser(attributes) {
            if (attributes === void 0) { attributes = {}; }
            this.attributes = attributes;
        }
        AuthUser.prototype.toJson = function () {
            return JSON.stringify(this.attributes);
        };
        Object.defineProperty(AuthUser.prototype, "name", {
            get: function () {
                return this.attributes.name;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(AuthUser.prototype, "id", {
            get: function () {
                return this.attributes.id;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(AuthUser.prototype, "token", {
            get: function () {
                return this.attributes.token;
            },
            set: function (value) {
                this.attributes.token = value;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(AuthUser.prototype, "avatar", {
            get: function () {
                return this.attributes.avatar;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(AuthUser.prototype, "provider", {
            get: function () {
                return this.attributes.provider;
            },
            enumerable: true,
            configurable: true
        });
        return AuthUser;
    }());
    var SocialMediaAuthService = /** @class */ (function () {
        function SocialMediaAuthService(providers) {
            if (providers === void 0) { providers = []; }
            this.providers = {};
            this.user = null;
            providers.map(this.registerProvider.bind(this));
        }
        SocialMediaAuthService.prototype.getProvider = function (providerName) {
            if (!this.providers[providerName]) {
                throw new Error("Unkowwn '" + providerName + "' provider.");
            }
            return this.providers[providerName];
        };
        SocialMediaAuthService.prototype.getUser = function () {
            return this.user;
        };
        SocialMediaAuthService.prototype.persistUser = function () {
            localStorage.setItem('sma:user', this.user.toJson());
        };
        SocialMediaAuthService.prototype.forgetUser = function () {
            localStorage.removeItem('sma:user');
        };
        SocialMediaAuthService.prototype.recoverUser = function () {
            var _this = this;
            var def = jQuery.Deferred();
            var userAttributes = JSON.parse(localStorage.getItem('sma:user'));
            if (userAttributes) {
                this.user = new AuthUser(userAttributes);
                this.getProvider(this.user.provider)
                    .check(this.user)
                    .then(function (response) {
                    def.resolve(_this.user);
                })
                    .fail(function (response) {
                    def.reject();
                });
            }
            else {
                def.reject();
            }
            return def;
        };
        SocialMediaAuthService.prototype.registerProvider = function (provider) {
            this.providers[provider.name()] = provider;
        };
        SocialMediaAuthService.prototype.setUser = function (userAttributes) {
            this.user = new AuthUser(userAttributes);
            this.persistUser();
        };
        SocialMediaAuthService.prototype.setupProviders = function () {
            var providers = [];
            for (var providerName in this.providers) {
                providers.push(this.getProvider(providerName).setup());
            }
            return jQuery.when.apply(jQuery, providers);
        };
        return SocialMediaAuthService;
    }());
    var SocialMediaAuthHandler = /** @class */ (function () {
        function SocialMediaAuthHandler(service) {
            this.service = service;
            this.setupProviders();
            this.bindLoginButtons();
            this.bindLogoutButton();
        }
        SocialMediaAuthHandler.prototype.bindLoginButtons = function () {
            var _this = this;
            jQuery(document).on('click', '[totalpoll-sma-login]', function (event) { return _this.handleLogin(event); });
        };
        SocialMediaAuthHandler.prototype.bindLogoutButton = function () {
            var _this = this;
            jQuery(document).on('click', '[totalpoll-sma-logout]', function (event) { return _this.handleLogout(event); });
        };
        SocialMediaAuthHandler.prototype.handleLogin = function (event) {
            var _this = this;
            event.preventDefault();
            var $button = jQuery(event.currentTarget);
            var provider = $button.attr('totalpoll-sma-login');
            this.service.getProvider(provider)
                .login()
                .then(function (userAttributes) {
                _this.service.setUser(userAttributes);
                _this.setupUser();
            });
        };
        SocialMediaAuthHandler.prototype.handleLogout = function (event) {
            event.preventDefault();
            this.service.forgetUser();
            top.location.reload();
        };
        SocialMediaAuthHandler.prototype.setupProviders = function () {
            var _this = this;
            TotalPoll.Hooks.doAction('totalpoll/sma/setupProvider', this);
            this.service.setupProviders()
                .then(function () {
                _this.service
                    .recoverUser()
                    .then(function (user) { return _this.setupUser(); });
            });
            TotalPoll.Hooks.addAction('totalpoll/init', function (poll) {
                if (poll.element.find('[totalpoll-sma-on-vote]').length) {
                    poll.element.find('button[value="vote"]').on('click', function (event) {
                        if (!_this.setupUser()) {
                            return false;
                        }
                    });
                }
                else {
                    _this.setupUser();
                }
            });
        };
        SocialMediaAuthHandler.prototype.setupUser = function () {
            var user = this.service.getUser();
            if (user) {
                var template_1 = jQuery('[totalpoll-sma-user-template]').html();
                jQuery('[totalpoll-sma-container]').each(function (index, el) {
                    var $el = jQuery(el);
                    $el.parent().find('form').prepend(template_1.replace(/\{\{user\.(.*?)\}\}/g, function (match, prop) { return user[prop]; }));
                    $el.remove();
                });
            }
            else {
                jQuery('[totalpoll-sma-container]').addClass('active');
            }
            return user;
        };
        return SocialMediaAuthHandler;
    }());
    var FacebookLoginAuthProvider = /** @class */ (function () {
        function FacebookLoginAuthProvider() {
        }
        FacebookLoginAuthProvider.prototype.check = function (user) {
            var def = jQuery.Deferred();
            FB.getLoginStatus(function (response) {
                if (response.authResponse && user.id === response.authResponse.userID) {
                    user.token = response.authResponse.accessToken;
                    def.resolve(user);
                }
                else {
                    def.reject();
                }
            });
            return def;
        };
        FacebookLoginAuthProvider.prototype.login = function () {
            var _this = this;
            var def = jQuery.Deferred();
            FB.login(function (response) {
                if (response.authResponse) {
                    FB.api('/me', function (userResponse) {
                        def.resolve({
                            id: userResponse.id,
                            provider: _this.name(),
                            token: response.authResponse.accessToken,
                            name: userResponse.name,
                            avatar: "https://graph.facebook.com/" + userResponse.id + "/picture?type=square"
                        });
                    });
                }
            }, { scope: 'email' });
            return def;
        };
        FacebookLoginAuthProvider.prototype.logout = function (user) {
        };
        FacebookLoginAuthProvider.prototype.name = function () {
            return 'facebook';
        };
        FacebookLoginAuthProvider.prototype.setup = function () {
            var def = jQuery.Deferred();
            if (!window['fbAsyncInit']) {
                window['fbAsyncInit'] = function () {
                    FB.init({
                        appId: TotalPollSocialMediaAuth.facebook.appId,
                        cookie: true,
                        xfbml: true,
                        version: 'v3.2'
                    });
                    def.resolve();
                };
            }
            (function (d, s, id) {
                var js, fjs = d.getElementsByTagName(s)[0];
                if (d.getElementById(id)) {
                    return;
                }
                js = d.createElement(s);
                js.id = id;
                js.src = "https://connect.facebook.net/en_US/sdk.js";
                fjs.parentNode.insertBefore(js, fjs);
            }(document, 'script', 'facebook-jssdk'));
            return def;
        };
        return FacebookLoginAuthProvider;
    }());
    var GoogleLoginAuthProvider = /** @class */ (function () {
        function GoogleLoginAuthProvider() {
        }
        GoogleLoginAuthProvider.prototype.check = function (user) {
            var def = jQuery.Deferred();
            if (gapi.auth2.getAuthInstance().isSignedIn.get()) {
                def.resolve(user);
            }
            else {
                def.reject();
            }
            return def;
        };
        GoogleLoginAuthProvider.prototype.login = function () {
            var _this = this;
            var def = jQuery.Deferred();
            gapi.auth2.getAuthInstance().signIn()
                .then(function (userResponse) {
                def.resolve({
                    id: userResponse.getId(),
                    provider: _this.name(),
                    token: userResponse.getAuthResponse(true).id_token,
                    name: userResponse.getBasicProfile().getName(),
                    avatar: userResponse.getBasicProfile().getImageUrl()
                });
            });
            return def;
        };
        GoogleLoginAuthProvider.prototype.logout = function (user) {
        };
        GoogleLoginAuthProvider.prototype.name = function () {
            return 'google';
        };
        GoogleLoginAuthProvider.prototype.setup = function () {
            var def = jQuery.Deferred();
            window['gapisInit'] = function () {
                gapi.load('auth2', function () {
                    // Retrieve the singleton for the GoogleAuth library and set up the client.
                    var auth2 = gapi.auth2.init({
                        client_id: TotalPollSocialMediaAuth.google.clientId,
                        cookiepolicy: 'single_host_origin',
                    }).then(function () { return def.resolve(); });
                });
            };
            var script = document.createElement('script');
            script.src = 'https://apis.google.com/js/platform.js?onload=gapisInit';
            document.head.appendChild(script);
            return def;
        };
        return GoogleLoginAuthProvider;
    }());
    var service = new SocialMediaAuthService([
        new FacebookLoginAuthProvider(),
        new GoogleLoginAuthProvider(),
    ]);
    var handler = new SocialMediaAuthHandler(service);
})(TotalPoll || (TotalPoll = {}));

//# sourceMappingURL=maps/social-media-auth.js.map
