<?php

namespace TotalPoll\Modules\Extensions\Stats;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Poll\Model;
use TotalPollVendors\TotalCore\Helpers\Strings;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\Redirect
 */
class Shortcode extends \TotalPollVendors\TotalCore\Shortcodes\Shortcode {
	/**
	 * Handle shortcode.
	 *
	 * @return mixed
	 * @since 1.0.0
	 */
	public function handle() {
		/**
		 * @var Model $poll
		 */
		$poll = TotalPoll( 'polls.repository' )->getById( $this->getAttribute( 'id' ) );
		if ( ! $poll ):
			return null;
		endif;

		$questions = [];
		foreach ( $poll->getQuestionsForResults() as $index => $question ):
			$questionFiltered = [
				'content' => $question['content'],
				'votes'   => $poll->getQuestionVotesWithLabel( $question['uid'] ),
				'choices' => [],
			];
			foreach ( $question['choices'] as $choice ):
				$choiceFiltered = [
					'label'           => $choice['label'],
					$choice['type']   => empty( $choice[ $choice['type'] ] ) ? [] : $choice[ $choice['type'] ],
					'votes'           => $poll->getChoiceVotesNumber( $choice['uid'] ),
					'votesFormatted'  => $poll->getChoiceVotesFormatted( $choice['uid'] ),
					'votesPercentage' => $poll->getChoiceVotesPercentageWithLabel( $choice['uid'] ),
				];

				$questionFiltered['choices'][]                 = $choiceFiltered;
				$questionFiltered['choices'][ $choice['uid'] ] = $choiceFiltered;
			endforeach;

			$questions[]                   = $questionFiltered;
			$questions[ $question['uid'] ] = $questionFiltered;
		endforeach;

		return Strings::template(
			$this->getAttribute( 'text', $this->getContent() ),
			[
				'totalVotes'          => $poll->getTotalVotes(),
				'totalVotesFormatted' => $poll->getTotalVotesNumber(),
				'totalVotesWithLabel' => $poll->getTotalVotesWithLabel(),
				'questions'           => $questions,
			]
		);
	}
}