<?php /** @noinspection PhpIncludeInspection */

namespace TotalPoll\Modules\Extensions\VoteConfirmation\Concerns;
! defined( 'ABSPATH' ) && exit();


use TotalPollVendors\TotalCore\Helpers\Arrays;
use WP_User;

trait EmailConfirmationHelper {

	/**
	 * @return string
	 */
	public function getSubject() {
		$message = $this->getOption( 'subject', '' );
		return empty($message) ? $this->getDefaultMessage( 'subject' ) : $message;
	}

	/**
	 * @return string
	 */
	public function getBody() {
		$message = $this->getOption( 'body', '' );
		return empty($message) ? $this->getDefaultMessage( 'body' ) : $message;
	}

	/**
	 * @return string
	 */
	public function getMessage() {
		$message = $this->getOption( 'message', '' );
		return empty($message) ? $this->getDefaultMessage( 'message' ) : $message;
	}

	/**
	 * @return string
	 */
	public function getConfirmation() {
		$message = $this->getOption( 'confirmation', '' );
		return empty($message) ? $this->getDefaultMessage( 'confirmation' ) : $message;
	}

	/**
	 * @param array $pollSettings
	 *
	 * @return bool
	 */
	public function isConfirmationExcluded( $pollSettings ) {

		return Arrays::getDotNotation( $pollSettings, static::OPTION_NAME . '.excluded', false );
	}

	/**
	 * @param array $fields
	 *
	 * @return bool
	 */
	protected function hasField( $fields ) {
		return in_array( static::FIELD_NAME, array_column( $fields, 'name' ), true );
	}

	/**
	 * @return bool
	 */
	public function isEnabled() {
		return (bool) $this->getOption( 'enabled', false );
	}

	/**
	 * @return bool
	 */
	public function isUnique() {
		return (bool) $this->getOption( 'unique', false );
	}

	/**
	 * @return bool
	 */
	public function getFieldLabel() {
		return (string) $this->getOption( 'fieldLabel', esc_html__( 'Email', 'totalpoll' ) );
	}

	/**
	 * @param array $data
	 *
	 * @return false|string
	 */
	public function renderTemplate( $data = [] ) {
		ob_start();
		extract( $data );
		require $this->getPath( 'views/email.php' );

		return ob_get_clean();
	}

	public function getUserName() {
		$user = wp_get_current_user();

		if ( $user instanceof WP_User ) {
			return $user->display_name;
		}

		return null;
	}

	public function getDefaultMessage( $message ) {
		return $this->defaultsMessages[ $message ];
	}
}
