<?php

namespace TotalPoll\Modules\Extensions\VoteWeight;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Poll\Model;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\VoteWeight
 */
class Extension extends \TotalPoll\Modules\Extension {
	protected $root = __FILE__;

	/**
	 * @var int
	 */
	protected $voteWeight = null;

	/**
	 * @var string
	 */
	protected $role = null;

	/**
	 * Run the extension.
	 *
	 * @return void
	 */
	public function run() {
		add_filter( 'totalpoll/filters/admin/options/tabs', [ $this, 'tab' ] );
		add_filter( 'totalpoll/filters/poll/choices/count', [ $this, 'countVote' ], 10, 2 );
	}


	/**
	 * @param array $tabs
	 *
	 * @return array
	 */
	public function tab( $tabs ) {

		$tabs['vote-weight'] = [
			'label' => esc_html__( 'Vote Weight', 'totalpoll' ),
			'icon'  => 'superhero-alt',
			'file'  => $this->getPath( 'views/tab.php' )
		];

		return $tabs;
	}

	public function countVote( $choices, Model $poll ) {
		$weightByRoles = Totalpoll()->option( 'voteWeight.roles', [] );
		$this->role    = is_user_logged_in() ? current( wp_get_current_user()->roles ) : 'guest';

		if ( isset( $weightByRoles[ $this->role ] ) ) {
			$this->voteWeight = empty( $weightByRoles[ $this->role ] ) ? 1 : abs( $weightByRoles[ $this->role ] );
			foreach ( $choices as $index => $choice ) {
				$choices[ $index ]['votes'] = $this->voteWeight;
				$poll->incrementChoiceVotes( $choice['uid'], $this->voteWeight - $choice['votes'] );
			}

			add_filter( 'totalpoll/filters/poll/command/log/attributes', [ $this, 'log' ] );
		}

		return $choices;
	}

	public function log( $attributes ) {
		if ( $this->voteWeight ) {
			$attributes['details']['voteWeightRole'] = $this->role;
			$attributes['details']['voteWeight']     = $this->voteWeight;
		}

		return $attributes;
	}
}
