<?php

namespace TotalPoll\Modules\Extensions\WooCommerce;
! defined( 'ABSPATH' ) && exit();


use TotalPoll\Poll\Model;

/**
 * Class Extension
 * @package TotalPoll\Modules\Extensions\WooCommerce
 */
class Extension extends \TotalPoll\Modules\Extension {
	protected $root = __FILE__;
	protected $orderId = null;

	/**
	 * Run the extension.
	 *
	 * @return mixed
	 */
	public function run() {
		add_filter( 'woocommerce_get_settings_pages', [ $this, 'wcSettingsPages' ] );
		add_action( 'woocommerce_thankyou', [ $this, 'afterCheckout' ] );
		add_action( 'totalpoll/actions/bootstrap', [ $this, 'setup' ] );
	}

	public function wcSettingsPages( $pages ) {
		$pages[] = new WooCommerceSettings();

		return $pages;
	}

	public function setup() {
		$pollId = (int) get_option( 'totalpoll_woocommerce_extension_after_checkout' );

		if ( ! empty( $pollId ) ):
			// Override results
			add_filter(
				'totalpoll/filters/render/output',
				function ( $output, $renderedPoll ) use ( $pollId ) {
					if ( $renderedPoll->getId() === $pollId && $renderedPoll->isResultsScreen() ) :
						return null;
					endif;

					return $output;
				},
				10, 2
			);

			// Hidden field to capture order ID
			add_filter( 'totalpoll/filters/form/pages', function ( $pages, $renderedPoll ) use ( $pollId ) {
				if ( $renderedPoll->getId() === $pollId ):
					$orderIdField = TotalPoll( 'form.factory' )->makeTextField();
					$orderIdField->setName( 'wc_order_id' );
					$orderIdField->setOptions(
						[
							'type'  => 'hidden',
							'name'  => 'totalpoll[wc_order_id]',
							'label' => false,
						]
					);
					$orderIdField->setValue( $this->orderId );

					$pages['hiddenFields'][] = $orderIdField;
				endif;

				return $pages;
			}, 10, 2 );

			// Add to log
			add_filter( 'totalpoll/filters/poll/command/log/attributes', function ( $attrs ) use ( $pollId ) {
				if ( $attrs['poll_id'] === $pollId ):
					$attrs['details']['wc_order_id'] = [ (int) TotalPoll( 'http.request' )->post( 'totalpoll.wc_order_id' ) ];
				endif;

				return $attrs;
			} );

			add_filter( 'totalpoll/filters/admin/log/columns', function ( $cols ) {
				$cols['order_id'] = [
					'label'   => esc_html__( 'WooCommerce Order ID', 'totalpoll' ),
					'content' => sprintf( '<a href="%s" target="_blank">%s</a>', admin_url( "post.php?post={{item.getDetails().wc_order_id}}&action=edit" ), "{{ item.getDetails().wc_order_id }}" ),
					'default' => false,
				];

				return $cols;
			} );

			add_action( 'totalpoll/actions/admin/log/modal/after', function () {
				$orderLabel = esc_html__( 'WooCommerce Order', 'totalpoll' );
				$link       = sprintf( '<a href="%s" target="_blank">%s</a>', admin_url( "post.php?post={{\$ctrl.currentItem.getDetails().wc_order_id}}&action=edit" ), "{{ \$ctrl.currentItem.getDetails().wc_order_id }}" );
				echo <<<HTML
                        <tr ng-if="\$ctrl.currentItem.getDetails().wc_order_id">
                            <th colspan="2">{$orderLabel}</th>
                        </tr>
                        <tr  ng-if="\$ctrl.currentItem.getDetails().wc_order_id">
                            <td colspan="2">{$link}</td>
                        </tr>
HTML;

			} );

			// Hide results buttons
			add_filter( 'totalpoll/filters/form/buttons', function ( $buttons, $renderedPoll ) use ( $pollId ) {
				if ( $renderedPoll->getId() === $pollId ) :
					if ( ! $renderedPoll->isAcceptingVotes() ):
						return [];
					endif;

					if ( $renderedPoll->isVoteScreen() ):
						$buttons = array_filter( $buttons, function ( $button ) {
							return $button->getAttribute( 'value' ) !== Model::RESULTS_ACTION;
						} );
					endif;
				endif;

				return $buttons;
			}, 10, 2 );
		endif;
	}

	public function afterCheckout( $orderId ) {
		$this->orderId = $orderId;
		$pollId        = get_option( 'totalpoll_woocommerce_extension_after_checkout' );
		$excluded      = array_filter( explode( ',', get_option( 'totalpoll_woocommerce_extension_exclude_products' ) ) );
		$included      = array_filter( explode( ',', get_option( 'totalpoll_woocommerce_extension_include_products' ) ) );

		$order       = wc_get_order( $this->orderId );
		$items       = $order->get_items();
		$productsIds = [];
		foreach ( $items as $item ) {
			if ( $item instanceof \WC_Order_Item_Product ) {
				$productsIds[] = $item->get_product_id();
			}
		}

		if ( ! empty( $excluded ) && ! empty( array_intersect( $productsIds, $excluded ) ) ) {
			return;
		}

		if ( ! empty( $included ) && empty( array_intersect( $productsIds, $included ) ) ) {
			return;
		}

		if ( ! empty( $pollId ) ):
			$poll = TotalPoll( 'polls.repository' )->getById( $pollId );

			if ( $poll ):
				echo $poll->render();
			endif;
		endif;
	}
}
