<?php

namespace TotalPoll\Modules\Extensions\WooCommerce;
! defined( 'ABSPATH' ) && exit();


use WC_Settings_Page;

class WooCommerceSettings extends WC_Settings_Page {
	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'polls';
		$this->label = esc_html__( 'Polls', 'totalpoll' );

		parent::__construct();
	}


	/**
	 * Get sections.
	 *
	 * @return array
	 */
	public function get_sections() {
		$sections = array(
			'' => esc_html__( 'General', 'woocommerce' ),
		);

		return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
	}

	public function get_settings( $current_section = '' ) {
		$polls   = get_posts( [ 'post_type' => 'poll' ] );
		$options = [ '' => esc_html__( 'None', 'totalpoll' ) ];
		foreach ( $polls as $poll ):
			$options[ $poll->ID ] = $poll->post_title;
		endforeach;

		return apply_filters( 'woocommerce_get_settings_' . $this->id, [
			[
				'name' => esc_html__( 'Polls', 'totalpoll' ),
				'type' => 'title',
				'desc' => '',
				'id'   => 'totalpoll_woocommerce_extension',
			],

			[
				'type'     => 'select',
				'id'       => 'totalpoll_woocommerce_extension_after_checkout',
				'name'     => esc_html__( 'After checkout', 'totalpoll' ),
				'options'  => $options,
				'class'    => 'wc-enhanced-select',
				'desc_tip' => esc_html__( 'This poll will be shown to customer after checkout', 'totalpoll' ),
				'default'  => '',
			],

			[
				'type'     => 'text',
				'id'       => 'totalpoll_woocommerce_extension_exclude_products',
				'name'     => esc_html__( 'Exclude products IDs', 'totalpoll' ),
				'desc'     => esc_html__( 'Use comma between IDs', 'totalpoll' ),
				'class'    => '',
				'desc_tip' => esc_html__( 'This poll will not be shown if the order contains the defined product IDs', 'totalpoll' ),
				'default'  => '',
			],

			[
				'type'     => 'text',
				'id'       => 'totalpoll_woocommerce_extension_include_products',
				'name'     => esc_html__( 'Include products IDs', 'totalpoll' ),
				'desc'     => esc_html__( 'Use comma between IDs', 'totalpoll' ),
				'class'    => '',
				'desc_tip' => esc_html__( 'This poll will be shown only if the order contains the defined product IDs', 'totalpoll' ),
				'default'  => '',
			],

			[
				'type' => 'sectionend',
				'id'   => 'totalpoll_woocommerce_extension',
			],
		] );

	}
}
