<?php

namespace TotalPoll\Modules\Templates\ChartsLegacy;
! defined( 'ABSPATH' ) && exit();


class Template extends \TotalPoll\Modules\Template {
	protected $root = __FILE__;

	public function assets() {
		wp_enqueue_script( 'chart-js', $this->getUrl( 'assets/scripts/chart.bundle.min.js' ), [ 'totalpoll-poll' ] );
		wp_enqueue_script( 'charts-template', $this->getUrl( 'assets/scripts/charts.js' ), [ 'chart-js' ] );
	}

	public function getChartData( $question ) {
		$chartData = [];
		$chartType = $this->getChartType();
		foreach ( $question['choices'] as $choice ):
			if ( empty( $choice['visibility'] ) ):
				continue;
			endif;
			// Set choice labels
			$chartData['labels'][] = $choice['label'];
			// The data set
			$chartData['datasets'][0]['label'] = $choice['label'];
			$chartData['datasets'][0]['data'][]   = $this->getPoll()->getChoiceVotesPercentage( $choice['uid'] );
			$chartData['datasets'][0]['text'][]   = $this->getPoll()->getChoiceVotesFormatted( $choice['uid'] );
			$colors                               = [
				'#F44336',
				'#E91E63',
				'#9C27B0',
				'#673AB7',
				'#3F51B5',
				'#2196F3',
				'#03A9F4',
				'#00BCD4',
				'#009688',
				'#4CAF50',
				'#8BC34A',
				'#CDDC39',
				'#FFEB3B',
				'#FFC107',
				'#FF9800',
				'#FF5722',
				'#795548',
				'#9E9E9E',
				'#607D8B'
			];
			shuffle( $colors );
			$color = array_shift( $colors );

			if ( $chartType === 'line' || $chartType === 'radar' ):
				$chartData['datasets'][0]['pointBackgroundColor'][] = $color;
				$chartData['datasets'][0]['pointBorderColor'][]     = $color;
				$chartData['datasets'][0]['backgroundColor'][]      = 'rgba(0,0,0,0)';
				$chartData['datasets'][0]['borderColor'][]          = '#555555';
			else:
				$chartData['datasets'][0]['backgroundColor'][]      = $color;
				$chartData['datasets'][0]['hoverBackgroundColor'][] = $color;
			endif;
		endforeach;

		return $chartData;
	}

	/**
	 * @return string
	 */
	public function getChartAnimationDuration() {
		return $this->getPoll()->getSettingsItem( 'design.custom.chart.animation.duration', 1000 );
	}

	/**
	 * @return string
	 */
	public function getAnimationChartEasing() {
		return $this->getPoll()->getSettingsItem( 'design.custom.chart.animation.easing', 'easeOutQuart' );
	}

	/**
	 * @return string
	 */
	public function getChartWidth() {
		return $this->getPoll()->getSettingsItem( 'design.custom.chart.size.width', 400 );
	}

	/**
	 * @return string
	 */
	public function getChartHeight() {
		return $this->getPoll()->getSettingsItem( 'design.custom.chart.size.height', 200 );
	}

	/**
	 * @return string
	 */
	public function getChartType() {
		return $this->getPoll()->getSettingsItem( 'design.custom.chart.canvas.type', 'doughnut' );
	}

	/**
	 * @return bool
	 */
	public function isLegendVisible() {
		return $this->getPoll()->getSettingsItem( 'design.custom.chart.legend.visible', false );
	}
}
