"use strict";
var TotalPoll;
(function (TotalPoll) {
    var QuestionChartCanvas = /** @class */ (function () {
        function QuestionChartCanvas($canvas, poll) {
            var _this = this;
            this.$canvas = $canvas;
            this.poll = poll;
            this.settings = {
                data: [],
                type: 'bar',
                options: {
                    tooltips: {},
                    legend: {
                        display: true,
                        position: "bottom",
                        align: "center",
                        labels: {
                            padding: 30,
                        },
                    },
                    animation: {
                        duration: '1000',
                        easing: 'easeOut'
                    }
                }
            };
            this.settings.data = JSON.parse(this.$canvas.attr('totalpoll-chart-data'));
            this.settings.type = this.$canvas.attr('totalpoll-chart-type');
            if (this.settings.type === 'bar') {
                this.settings.options.legend.display = false;
                this.settings.options.scales = {
                    yAxes: [{
                            ticks: {
                                beginAtZero: true,
                                callback: function (value, index, values) {
                                    return value + '%';
                                }
                            }
                        }]
                };
            }
            this.settings.options.tooltips.callbacks = {
                label: function (tooltipItem, data) {
                    return "\t" + data.labels[tooltipItem.index] + ": " + data.datasets[0].text[tooltipItem.index];
                }
            };
            this.settings.options.animation.duration = this.$canvas.attr('totalpoll-chart-animation-duration');
            this.settings.options.animation.easing = this.$canvas.attr('totalpoll-chart-animation-easing');
            this.$choices = this.$canvas.next('.totalpoll-question-choices').find('.totalpoll-question-choices-item');
            setTimeout(function () {
                _this.setupChart();
                _this.setupChoicesTooltips();
            }, poll.config['effects']['duration']);
        }
        QuestionChartCanvas.prototype.setupChart = function () {
            this.chart = new Chart(this.$canvas.get(0), this.settings);
        };
        QuestionChartCanvas.prototype.setupChoicesTooltips = function () {
            var _this = this;
            // Initialize tooltips for legend items
            this.$choices.each(function (index, el) {
                var tooltipSettings = {
                    _chart: _this.chart.chart,
                    _chartInstance: _this.chart,
                    _data: _this.chart.data,
                    _options: _this.chart.options.tooltips,
                    _active: [_this.chart.getDatasetMeta(0).data[index]]
                };
                var tooltip = new Chart.Tooltip(tooltipSettings, _this.chart);
                jQuery(el).data('totalpoll-chart-choice-tooltip', tooltip);
                tooltip.initialize();
            });
            // Draw tooltips on legend mouseover
            this.$choices.mouseover(function () {
                var tooltip = jQuery(this).data('totalpoll-chart-choice-tooltip');
                tooltip.update();
                tooltip.pivot();
                tooltip.transition('swing').draw();
            });
            // Remove tooltip on legend mouseout
            this.$choices.mouseout(function () {
                _this.chart.draw();
            });
        };
        return QuestionChartCanvas;
    }());
    TotalPoll.QuestionChartCanvas = QuestionChartCanvas;
    // Any further actions
    TotalPoll['Hooks'].addAction("totalpoll/init", function (poll) {
        poll.element.find('[totalpoll-chart]').each(function (index, canvas) {
            new QuestionChartCanvas(jQuery(canvas), poll);
        });
    });
})(TotalPoll || (TotalPoll = {}));

//# sourceMappingURL=maps/charts.js.map
